========
Overview
========

.. start-badges

.. list-table::
    :stub-columns: 1

    * - docs
      - |docs|
    * - tests
      - | |travis|
        | |coveralls|
    * - package
      - |version| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/tweetstash/badge/?style=flat
    :target: https://readthedocs.org/projects/tweetstash
    :alt: Documentation Status

.. |travis| image:: https://travis-ci.org/hsharrison/tweetstash.svg?branch=master
    :alt: Travis-CI Build Status
    :target: https://travis-ci.org/hsharrison/tweetstash

.. |coveralls| image:: https://coveralls.io/repos/hsharrison/tweetstash/badge.svg?branch=master&service=github
    :alt: Coverage Status
    :target: https://coveralls.io/r/hsharrison/tweetstash

.. |version| image:: https://img.shields.io/pypi/v/tweetstash.svg?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/tweetstash

.. |downloads| image:: https://img.shields.io/pypi/dm/tweetstash.svg?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/tweetstash

.. |wheel| image:: https://img.shields.io/pypi/wheel/tweetstash.svg?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/tweetstash

.. |supported-versions| image:: https://img.shields.io/pypi/pyversions/tweetstash.svg?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/tweetstash

.. |supported-implementations| image:: https://img.shields.io/pypi/implementation/tweetstash.svg?style=flat
    :alt: Supported implementations
    :target: https://pypi.python.org/pypi/tweetstash


.. end-badges

Utility for collecting tweets.

* Free software: BSD license
  
**Note**: this project is currently set up minimally to run a single project.
Other features are planned.
In the meantime, if something is missing that you would need to use this, let me know
(or even better, submit a pull request).
